#
# spec file for package python-python-datamatrix
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-python-datamatrix
Version:        1.0.13
Release:        1.3
Summary:        A python library to work with tabular data
License:        GPL-3.0-or-later
URL:            https://github.com/open-cogsci/python-datamatrix
Source:         https://github.com/open-cogsci/python-datamatrix/archive/release/%{version}.tar.gz#/python-datamatrix-release-%{version}.tar.gz
BuildRequires:  %{python_module PrettyTable}
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module fastnumbers}
BuildRequires:  %{python_module flit-core >= 3.4}
BuildRequires:  %{python_module json_tricks}
BuildRequires:  %{python_module matplotlib}
BuildRequires:  %{python_module nibabel}
BuildRequires:  %{python_module nilearn}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module openpyxl}
BuildRequires:  %{python_module pandas}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module scipy}
BuildRequires:  %{python_module tomlkit}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-PrettyTable
Requires:       python-json_tricks
Requires:       python-numpy
Requires:       python-openpyxl
Requires:       python-psutil
Requires:       python-scipy
Requires:       python-tomlkit
Recommends:     python-fastnumbers
Recommends:     python-matplotlib
Recommends:     python-nibabel
Recommends:     python-nilearn
Recommends:     python-pandas
BuildArch:      noarch
%python_subpackages

%description
The datamatrix package provides a high way to work with tabular data in Python.
Tabular data is datasets that consist of named columns and numbered rows.

%package -n %{name}-doc
Summary:        Documentation for %{name}
Provides:       %{python_module python-datamatrix-doc = %{version}}

%description -n %{name}-doc
Documentation and examples for %{name}.

%prep
%setup -q -n datamatrix-release-%{version}
# wrong-file-end-of-line-encoding
sed -i 's/\r$//' doc-pelican/data/fratescu-replication-data-exp1.csv

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# 32-bit datatype and precision errors
if [ $(getconf LONG_BIT) -eq 32 ]; then
  donttest="or test_intcolumn or test_seriescolumn"
fi
%pytest ${$python_donttest} ${donttest:+ -k "not (${donttest:4})"}

%files %{python_files}
%license copyright
%doc readme.md
%{python_sitelib}/datamatrix/
%{python_sitelib}/datamatrix-%{version}.dist-info

%files -n %{name}-doc
%license copyright
%doc doc-pelican/content/pages/*
%doc doc-pelican/data/
%doc doc-pelican/include/api

%changelog
* Wed Mar 20 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.0.13:
  * Implement uninstiated columns for faster and more memory-efficient
    splitting
  * UninstantiatedColumn now passes unit tests
  * Fix instantiated splitting of uninstantiated columns
  * Fixes for multiprocessing
  * _blink_points() now finds blinks after a long one
  * blinkreconstruct: use std to detect blink offset
  * Avoid recursion errors in blink reconstruction
  * blinkreconstruct: fix missing array return
  * blinkreconstruct: better way to avoid infinite recursion
  * blinkreconstruct: unbreak reconstruction of good signals
  * stack_multiprocess: fix race-condition where output files could
    overwrite each other
  * blinkreconstruct: don't initialize processed_blink_points with empty list
  * Fix ops.groupby() for multidimensional columns
  * Allow MultiDimensionalColumns in mapping functions in series module
- Switch to pyproject macros.
- Sort out Requires vs Recommends.
- Split out docs into a seperate package.
* Fri Apr 14 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.0.2:
  * Initial implementation of multidimensionalcolumn
* Thu Jan 20 2022 Ben Greiner <code@bnavigator.de>
- Update to 0.13.2
  * series.blinkreconstruct(): use smoothed trace in advanced mode
  * Implement advanced blink-reconstruction mode
* Fri Apr 23 2021 Steve Kowalik <steven.kowalik@suse.com>
- Add json_tricks to the list of optional but unavailable dependencies.
* Fri Feb 19 2021 Ben Greiner <code@bnavigator.de>
- Update to 0.11.1
  * operations.group(): convert group-key to int
  * Fixes compatibility with some versions of NumPy which don't
    consider np.in64 to be int
- Changes in 0.11.0
  * Slightly improve compatibility with pandas further
- Drop python-python-datamatrix-remove-nose.patch merged upstream
  gh#open-cogsci/python-datamatrix#10
- Don't install and test optional but unavailable dependencies
  on python36 flavor (NEP 29)
* Wed Jul  1 2020 pgajdos@suse.com
- version update to 0.10.17
  * srs.reduce_(): raise TypeError on invalid input
  * Only use bytes() in safe_decode for Exceptions
- added patches
  fix do not depend on nose
  + python-python-datamatrix-remove-nose.patch
* Thu Jan 30 2020 Todd R <toddrme2178@gmail.com>
- Update to 0.10.15
  * Upgrade old-style DataMatrix objects during memoization
  * Add shape property to DataMatrix
* Wed Oct 30 2019 Todd R <toddrme2178@gmail.com>
- Use noun statement for summary.
- Make summary more descriptive.
- Make description more objective.
- Fix rpmlint issue.
* Fri Sep 13 2019 Todd R <toddrme2178@gmail.com>
- Update to 0.10.12
  * Fix setting by DataMatrix for NumericColumn
  * Fix deprecated Index objects after unpickling
  * convert.to_dataframe(): don't crash on numeric column names
  * Add BOM data for unit tests
  * Enable universal newlines mode in Python 3
  * io.readtxt(): strip BOMs from column names
  * Gracefully accept any iterable object
- Drop python2 support because dependencies dropped python2 support
* Wed Mar 20 2019 John Vandenberg <jayvdb@gmail.com>
- Convert to single spec
- Activate test suite, skipping five failing test methods
- Add Recommends for numerical packages datamatrix supports
- Add %%license and %%doc
- Update to v0.9.14
* Thu Nov 10 2016 avvissu@yandex.by
- Initial package for v0.3.1
